#!/usr/bin/env python3
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

from mastodon import Mastodon
import argparse, sys, traceback, random, sqlite3, re

parser = argparse.ArgumentParser(description='Generate and post a toot.')
parser.add_argument('-s', '--simulate', dest='simulate', action='store_true',
	help="Print the toot to stdout without posting it")

args = parser.parse_args()

if not args.simulate:
	client = Mastodon(
		client_id="clientcred.secret",
		access_token="usercred.secret",
		api_base_url="https://botsin.space"
	)

db = sqlite3.connect("dict.db")
db.text_factory=str
c = db.cursor()
data = c.execute(r'SELECT word, definition FROM entries WHERE word LIKE "%ar%" AND wordtype LIKE "n." AND definition NOT LIKE "See%" AND definition NOT LIKE "Alt.%"').fetchall()
dset = random.choice(data)
definition = dset[1].replace("\n  ", "") # remove newlines from definitions
definition = definition.replace("etc.", "etc") # remove full stop from etc so as not to confuse the """algorithm"""
definition = re.search(r"^(?:An?|The)? ?([^.]*)", definition).group(1) # remove leading "A", "An", and "The", and stop at the first full stop
definition = definition[0].lower() + definition[1:] # make first letter lowercase
if " " not in definition:
	# "what's a pirate's favourite disembarkation? a debarrrkation!" doesn't make sense
	# so replace single words with "alternate word for {word}"
	# example: "what's a pirate's favourite alternate word for disembarkation? a debarrrkation!"
	# not perfect but much better
	definition = "alternative word for {}".format(definition)
cw = "What's a pirate's favourite {}?".format(definition)
toot = "A {}!".format(
	dset[0].lower().replace("ar", "a" + ('r' * random.randint(3,10)))
)

if not args.simulate:
	try:
		client.status_post(toot, visibility = 'unlisted', spoiler_text = cw)
	except Exception as err:
		toot = "Arr, @lynnesbian@fedi.lynnesbian.space, ye scallywag!" \
		+ " I've encountered an error most dire!" \
		+ " Check error.log in ye bot directory!!"
		with open("error.log", "w") as f:
			f.write("\n".join(traceback.format_tb(sys.exc_info()[2])))
		client.status_post(toot, visibility = 'unlisted', spoiler_text = "Error!")
print(cw)
print(toot)
